package Weather;

## Begin block will evaluated as the first thing during execution.
BEGIN {
   our $VERSION     = 1.00;

   our @ISA         = qw(Exporter);
   our @EXPORT      = qw( display_header display_daily_report display_weekly_report write_daily_report );
   our @EXPORT_OK   = qw();
   require Exporter;

   our $weather_report = { 
	# String
        place   => 'IIT Bombay, Powai', 
        nstate   => 'Maharastra',

	# Hash of Hash Reference
        weekly  => {                    
            monday => {
                max_temp => '40',
                min_temp => '34',
                sunrise   => '06.08 am',
                sunset    => '07.10 pm'
            },
            tuesday   => {
                max_temp => '41',
                min_temp => '32',
                sunrise   => '06.09 am',
                sunset    => '07.12 pm'
            },
            wednesday => {
                max_temp => '38',
                min_temp => '31',
                sunrise   => '06.10 am',
                sunset    => '07.11 pm'
            },
            thursday  => {
                max_temp => '41',
                min_temp => '33',
                sunrise   => '06.11 am',
                sunset    => '07.14 pm'
            },
            friday    => {
                max_temp => '42',
                min_temp => '30',
                sunrise   => '06.08 am',
                sunset    => '07.13 pm'
            }
        },
	# array reference
        record_time => ['11.00', '17.00'], 
    };
}


# This subroutine will display Report header
sub display_header {
    my $day = `date`;
    print '-' x 75;
    print "\n\n";
    print "\t\t\t Weather Report  \t\t\t";
    print "\n\n";
    print "\t\t\t", $weather_report->{place}, "\n"; # IIT Bombay, Powai
    print "\t\t\t", $weather_report->{nstate}, "\n"; # Maharastra
    print "\n";
    print '-' x 75 ."\n";
    print "Date: $day";
    print "\n";
}


sub trim($)
{
	my $string = shift;
	$string =~ s/^\s+//;
	$string =~ s/\s+$//;
	return $string;
}

# This subroutine will display daily report

sub display_daily_report {
 
 my $week_day =lc(trim(shift));
	
    if (exists $weather_report->{weekly}{$week_day}) {
        print "$week_day Report:\n\n";
        print "Max Temperature: " ,$weather_report->{weekly}{$week_day}{max_temp}, "\n";
        print "Min Temperature: " ,$weather_report->{weekly}{$week_day}{min_temp}, "\n";
        print "Record Time: ", $weather_report->{record_time}[0],",",$weather_report->{record_time}[1] ,"\n";
        print "Sunrise: " ,$weather_report->{weekly}{$week_day}{sunrise}, "\n";
        print "Sunset: ", $weather_report->{weekly}{$week_day}{sunset}, "\n";
        return 1;
    }
    else {
        print "Incorrect day input.";
        return 0;
    }
}


## Write daily Report to file
sub write_daily_report {

       my $week_day =lc(trim(shift));

    if (exists $weather_report->{weekly}{$week_day}) {
        open(my $FH, ">", "$week_day.txt") or die "Cannot open file";
	
        print $FH "$week_day Report:\n\n";
        print $FH "Max Temperature: " ,$weather_report->{weekly}{$week_day}{max_temp}, "\n";
        print $FH "Min Temperature: " ,$weather_report->{weekly}{$week_day}{min_temp}, "\n";
        print $FH "Record Time: ", $weather_report->{record_time}[0],",",$weather_report->{record_time}[1] ,"\n";
        print $FH "Sunrise: " ,$weather_report->{weekly}{$week_day}{sunrise}, "\n";
        print $FH "Sunset: ", $weather_report->{weekly}{$week_day}{sunset}, "\n";
	print $FH '-' x 75 ."\n";  
        close $FH;
        return 1;
    }
    else {
        print "Incorrect day input.";
        return 0;
    }
}


## This subroutine will display weekly report
sub display_weekly_report {
       foreach my $week_day (keys % {$weather_report->{weekly}}) {
        display_daily_report($week_day);
        print "\n\n";
    }
}

1;
